# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class InlineResponse2003KeyInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'organization_id': 'str',
        'reference_number': 'str',
        'key_id': 'str',
        'status': 'str',
        'message': 'str',
        'error_information': 'InlineResponse201ErrorInformation'
    }

    attribute_map = {
        'organization_id': 'organizationId',
        'reference_number': 'referenceNumber',
        'key_id': 'keyId',
        'status': 'status',
        'message': 'message',
        'error_information': 'errorInformation'
    }

    def __init__(self, organization_id=None, reference_number=None, key_id=None, status=None, message=None, error_information=None):
        """
        InlineResponse2003KeyInformation - a model defined in Swagger
        """

        self._organization_id = None
        self._reference_number = None
        self._key_id = None
        self._status = None
        self._message = None
        self._error_information = None

        if organization_id is not None:
          self.organization_id = organization_id
        if reference_number is not None:
          self.reference_number = reference_number
        if key_id is not None:
          self.key_id = key_id
        if status is not None:
          self.status = status
        if message is not None:
          self.message = message
        if error_information is not None:
          self.error_information = error_information

    @property
    def organization_id(self):
        """
        Gets the organization_id of this InlineResponse2003KeyInformation.
        Merchant Id 

        :return: The organization_id of this InlineResponse2003KeyInformation.
        :rtype: str
        """
        return self._organization_id

    @organization_id.setter
    def organization_id(self, organization_id):
        """
        Sets the organization_id of this InlineResponse2003KeyInformation.
        Merchant Id 

        :param organization_id: The organization_id of this InlineResponse2003KeyInformation.
        :type: str
        """

        self._organization_id = organization_id

    @property
    def reference_number(self):
        """
        Gets the reference_number of this InlineResponse2003KeyInformation.
        Reference number is a unique identifier provided by the client along with the organization Id. This is an optional field provided solely for the client’s convenience. If client specifies value for this field in the request, it is expected to be available in the response. 

        :return: The reference_number of this InlineResponse2003KeyInformation.
        :rtype: str
        """
        return self._reference_number

    @reference_number.setter
    def reference_number(self, reference_number):
        """
        Sets the reference_number of this InlineResponse2003KeyInformation.
        Reference number is a unique identifier provided by the client along with the organization Id. This is an optional field provided solely for the client’s convenience. If client specifies value for this field in the request, it is expected to be available in the response. 

        :param reference_number: The reference_number of this InlineResponse2003KeyInformation.
        :type: str
        """

        self._reference_number = reference_number

    @property
    def key_id(self):
        """
        Gets the key_id of this InlineResponse2003KeyInformation.
        Key Serial Number 

        :return: The key_id of this InlineResponse2003KeyInformation.
        :rtype: str
        """
        return self._key_id

    @key_id.setter
    def key_id(self, key_id):
        """
        Sets the key_id of this InlineResponse2003KeyInformation.
        Key Serial Number 

        :param key_id: The key_id of this InlineResponse2003KeyInformation.
        :type: str
        """

        self._key_id = key_id

    @property
    def status(self):
        """
        Gets the status of this InlineResponse2003KeyInformation.
        The status of the key.  Possible values:  - FAILED  - ACTIVE  - INACTIVE  - EXPIRED 

        :return: The status of this InlineResponse2003KeyInformation.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this InlineResponse2003KeyInformation.
        The status of the key.  Possible values:  - FAILED  - ACTIVE  - INACTIVE  - EXPIRED 

        :param status: The status of this InlineResponse2003KeyInformation.
        :type: str
        """

        self._status = status

    @property
    def message(self):
        """
        Gets the message of this InlineResponse2003KeyInformation.
        message in case of failed key

        :return: The message of this InlineResponse2003KeyInformation.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this InlineResponse2003KeyInformation.
        message in case of failed key

        :param message: The message of this InlineResponse2003KeyInformation.
        :type: str
        """

        self._message = message

    @property
    def error_information(self):
        """
        Gets the error_information of this InlineResponse2003KeyInformation.

        :return: The error_information of this InlineResponse2003KeyInformation.
        :rtype: InlineResponse201ErrorInformation
        """
        return self._error_information

    @error_information.setter
    def error_information(self, error_information):
        """
        Sets the error_information of this InlineResponse2003KeyInformation.

        :param error_information: The error_information of this InlineResponse2003KeyInformation.
        :type: InlineResponse201ErrorInformation
        """

        self._error_information = error_information

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, InlineResponse2003KeyInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class TaxesApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """
	
    def __init__(self, merchant_config, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client
        self.api_client.set_configuration(merchant_config) 


    def calculate_tax(self, tax_request, **kwargs):
        """
        Calculate Taxes
        Get tax details for a transaction. 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.calculate_tax(tax_request, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param TaxRequest tax_request: (required)
        :return: VasV2PaymentsPost201Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.calculate_tax_with_http_info(tax_request, **kwargs)
        else:
            (data) = self.calculate_tax_with_http_info(tax_request, **kwargs)
            return data

    def calculate_tax_with_http_info(self, tax_request, **kwargs):
        """
        Calculate Taxes
        Get tax details for a transaction. 
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.calculate_tax_with_http_info(tax_request, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param TaxRequest tax_request: (required)
        :return: VasV2PaymentsPost201Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['tax_request']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method calculate_tax" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'tax_request' is set
        if ('tax_request' not in params) or (params['tax_request'] is None):
            raise ValueError("Missing the required parameter `tax_request` when calling `calculate_tax`")


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'tax_request' in params:
            body_params = params['tax_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/hal+json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(f'/vas/v2/tax', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='VasV2PaymentsPost201Response',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def void_tax(self, void_tax_request, id, **kwargs):
        """
        Void Taxes
        Pass the Tax Request ID in the PATCH request to void the committed tax calculation.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.void_tax(void_tax_request, id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param VoidTaxRequest void_tax_request: (required)
        :param str id: The tax ID returned from a previous request. (required)
        :return: VasV2TaxVoid200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.void_tax_with_http_info(void_tax_request, id, **kwargs)
        else:
            (data) = self.void_tax_with_http_info(void_tax_request, id, **kwargs)
            return data

    def void_tax_with_http_info(self, void_tax_request, id, **kwargs):
        """
        Void Taxes
        Pass the Tax Request ID in the PATCH request to void the committed tax calculation.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.void_tax_with_http_info(void_tax_request, id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param VoidTaxRequest void_tax_request: (required)
        :param str id: The tax ID returned from a previous request. (required)
        :return: VasV2TaxVoid200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['void_tax_request', 'id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method void_tax" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'void_tax_request' is set
        if ('void_tax_request' not in params) or (params['void_tax_request'] is None):
            raise ValueError("Missing the required parameter `void_tax_request` when calling `void_tax`")
        # verify the required parameter 'id' is set
        if ('id' not in params) or (params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `void_tax`")


        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'void_tax_request' in params:
            body_params = params['void_tax_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/hal+json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(f'/vas/v2/tax/{id}', 'PATCH',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='VasV2TaxVoid200Response',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Riskv1decisionsMerchantInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'merchant_descriptor': 'Riskv1decisionsMerchantInformationMerchantDescriptor',
        'merchant_name': 'str'
    }

    attribute_map = {
        'merchant_descriptor': 'merchantDescriptor',
        'merchant_name': 'merchantName'
    }

    def __init__(self, merchant_descriptor=None, merchant_name=None):
        """
        Riskv1decisionsMerchantInformation - a model defined in Swagger
        """

        self._merchant_descriptor = None
        self._merchant_name = None

        if merchant_descriptor is not None:
          self.merchant_descriptor = merchant_descriptor
        if merchant_name is not None:
          self.merchant_name = merchant_name

    @property
    def merchant_descriptor(self):
        """
        Gets the merchant_descriptor of this Riskv1decisionsMerchantInformation.

        :return: The merchant_descriptor of this Riskv1decisionsMerchantInformation.
        :rtype: Riskv1decisionsMerchantInformationMerchantDescriptor
        """
        return self._merchant_descriptor

    @merchant_descriptor.setter
    def merchant_descriptor(self, merchant_descriptor):
        """
        Sets the merchant_descriptor of this Riskv1decisionsMerchantInformation.

        :param merchant_descriptor: The merchant_descriptor of this Riskv1decisionsMerchantInformation.
        :type: Riskv1decisionsMerchantInformationMerchantDescriptor
        """

        self._merchant_descriptor = merchant_descriptor

    @property
    def merchant_name(self):
        """
        Gets the merchant_name of this Riskv1decisionsMerchantInformation.
        Your company’s name as you want it to appear to the customer in the issuing bank’s authentication form. This value overrides the value specified by your merchant bank. 

        :return: The merchant_name of this Riskv1decisionsMerchantInformation.
        :rtype: str
        """
        return self._merchant_name

    @merchant_name.setter
    def merchant_name(self, merchant_name):
        """
        Sets the merchant_name of this Riskv1decisionsMerchantInformation.
        Your company’s name as you want it to appear to the customer in the issuing bank’s authentication form. This value overrides the value specified by your merchant bank. 

        :param merchant_name: The merchant_name of this Riskv1decisionsMerchantInformation.
        :type: str
        """
        if merchant_name is not None and len(merchant_name) > 25:
            raise ValueError("Invalid value for `merchant_name`, length must be less than or equal to `25`")

        self._merchant_name = merchant_name

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Riskv1decisionsMerchantInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2paymentsidrefundsProcessingInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'payment_solution': 'str',
        'reconciliation_id': 'str',
        'link_id': 'str',
        'report_group': 'str',
        'visa_checkout_id': 'str',
        'purchase_level': 'str',
        'recurring_options': 'Ptsv2paymentsidrefundsProcessingInformationRecurringOptions',
        'industry_data_type': 'str'
    }

    attribute_map = {
        'payment_solution': 'paymentSolution',
        'reconciliation_id': 'reconciliationId',
        'link_id': 'linkId',
        'report_group': 'reportGroup',
        'visa_checkout_id': 'visaCheckoutId',
        'purchase_level': 'purchaseLevel',
        'recurring_options': 'recurringOptions',
        'industry_data_type': 'industryDataType'
    }

    def __init__(self, payment_solution=None, reconciliation_id=None, link_id=None, report_group=None, visa_checkout_id=None, purchase_level=None, recurring_options=None, industry_data_type=None):
        """
        Ptsv2paymentsidrefundsProcessingInformation - a model defined in Swagger
        """

        self._payment_solution = None
        self._reconciliation_id = None
        self._link_id = None
        self._report_group = None
        self._visa_checkout_id = None
        self._purchase_level = None
        self._recurring_options = None
        self._industry_data_type = None

        if payment_solution is not None:
          self.payment_solution = payment_solution
        if reconciliation_id is not None:
          self.reconciliation_id = reconciliation_id
        if link_id is not None:
          self.link_id = link_id
        if report_group is not None:
          self.report_group = report_group
        if visa_checkout_id is not None:
          self.visa_checkout_id = visa_checkout_id
        if purchase_level is not None:
          self.purchase_level = purchase_level
        if recurring_options is not None:
          self.recurring_options = recurring_options
        if industry_data_type is not None:
          self.industry_data_type = industry_data_type

    @property
    def payment_solution(self):
        """
        Gets the payment_solution of this Ptsv2paymentsidrefundsProcessingInformation.
        Type of digital payment solution for the transaction. Possible Values:   - `visacheckout`: Visa Checkout. This value is required for Visa Checkout transactions. For details, see `payment_solution` field description in [Visa Checkout Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/VCO_SCMP_API/html/)  - `001`: Apple Pay.  - `004`: Cybersource In-App Solution.  - `005`: Masterpass. This value is required for Masterpass transactions on OmniPay Direct. For details, see \"Masterpass\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  - `006`: Android Pay.  - `007`: Chase Pay.  - `008`: Samsung Pay.  - `012`: Google Pay. 

        :return: The payment_solution of this Ptsv2paymentsidrefundsProcessingInformation.
        :rtype: str
        """
        return self._payment_solution

    @payment_solution.setter
    def payment_solution(self, payment_solution):
        """
        Sets the payment_solution of this Ptsv2paymentsidrefundsProcessingInformation.
        Type of digital payment solution for the transaction. Possible Values:   - `visacheckout`: Visa Checkout. This value is required for Visa Checkout transactions. For details, see `payment_solution` field description in [Visa Checkout Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/VCO_SCMP_API/html/)  - `001`: Apple Pay.  - `004`: Cybersource In-App Solution.  - `005`: Masterpass. This value is required for Masterpass transactions on OmniPay Direct. For details, see \"Masterpass\" in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  - `006`: Android Pay.  - `007`: Chase Pay.  - `008`: Samsung Pay.  - `012`: Google Pay. 

        :param payment_solution: The payment_solution of this Ptsv2paymentsidrefundsProcessingInformation.
        :type: str
        """
        if payment_solution is not None and len(payment_solution) > 12:
            raise ValueError("Invalid value for `payment_solution`, length must be less than or equal to `12`")

        self._payment_solution = payment_solution

    @property
    def reconciliation_id(self):
        """
        Gets the reconciliation_id of this Ptsv2paymentsidrefundsProcessingInformation.
        Please check with Cybersource customer support to see if your merchant account is configured correctly so you can include this field in your request. * For Payouts: max length for FDCCompass is String (22). 

        :return: The reconciliation_id of this Ptsv2paymentsidrefundsProcessingInformation.
        :rtype: str
        """
        return self._reconciliation_id

    @reconciliation_id.setter
    def reconciliation_id(self, reconciliation_id):
        """
        Sets the reconciliation_id of this Ptsv2paymentsidrefundsProcessingInformation.
        Please check with Cybersource customer support to see if your merchant account is configured correctly so you can include this field in your request. * For Payouts: max length for FDCCompass is String (22). 

        :param reconciliation_id: The reconciliation_id of this Ptsv2paymentsidrefundsProcessingInformation.
        :type: str
        """
        if reconciliation_id is not None and len(reconciliation_id) > 60:
            raise ValueError("Invalid value for `reconciliation_id`, length must be less than or equal to `60`")

        self._reconciliation_id = reconciliation_id

    @property
    def link_id(self):
        """
        Gets the link_id of this Ptsv2paymentsidrefundsProcessingInformation.
        Value that links the current authorization request to the original authorization request. Set this value to the ID that was returned in the reply message from the original authorization request.  This value is used for:  - Partial authorizations - Split shipments  For details, see `link_to_request` field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :return: The link_id of this Ptsv2paymentsidrefundsProcessingInformation.
        :rtype: str
        """
        return self._link_id

    @link_id.setter
    def link_id(self, link_id):
        """
        Sets the link_id of this Ptsv2paymentsidrefundsProcessingInformation.
        Value that links the current authorization request to the original authorization request. Set this value to the ID that was returned in the reply message from the original authorization request.  This value is used for:  - Partial authorizations - Split shipments  For details, see `link_to_request` field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :param link_id: The link_id of this Ptsv2paymentsidrefundsProcessingInformation.
        :type: str
        """
        if link_id is not None and len(link_id) > 26:
            raise ValueError("Invalid value for `link_id`, length must be less than or equal to `26`")

        self._link_id = link_id

    @property
    def report_group(self):
        """
        Gets the report_group of this Ptsv2paymentsidrefundsProcessingInformation.
        Attribute that lets you define custom grouping for your processor reports. This field is supported only for **Worldpay VAP**.  For details, see `report_group` field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :return: The report_group of this Ptsv2paymentsidrefundsProcessingInformation.
        :rtype: str
        """
        return self._report_group

    @report_group.setter
    def report_group(self, report_group):
        """
        Sets the report_group of this Ptsv2paymentsidrefundsProcessingInformation.
        Attribute that lets you define custom grouping for your processor reports. This field is supported only for **Worldpay VAP**.  For details, see `report_group` field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :param report_group: The report_group of this Ptsv2paymentsidrefundsProcessingInformation.
        :type: str
        """
        if report_group is not None and len(report_group) > 25:
            raise ValueError("Invalid value for `report_group`, length must be less than or equal to `25`")

        self._report_group = report_group

    @property
    def visa_checkout_id(self):
        """
        Gets the visa_checkout_id of this Ptsv2paymentsidrefundsProcessingInformation.
        Identifier for the **Visa Checkout** order. Visa Checkout provides a unique order ID for every transaction in the Visa Checkout **callID** field. 

        :return: The visa_checkout_id of this Ptsv2paymentsidrefundsProcessingInformation.
        :rtype: str
        """
        return self._visa_checkout_id

    @visa_checkout_id.setter
    def visa_checkout_id(self, visa_checkout_id):
        """
        Sets the visa_checkout_id of this Ptsv2paymentsidrefundsProcessingInformation.
        Identifier for the **Visa Checkout** order. Visa Checkout provides a unique order ID for every transaction in the Visa Checkout **callID** field. 

        :param visa_checkout_id: The visa_checkout_id of this Ptsv2paymentsidrefundsProcessingInformation.
        :type: str
        """
        if visa_checkout_id is not None and len(visa_checkout_id) > 48:
            raise ValueError("Invalid value for `visa_checkout_id`, length must be less than or equal to `48`")

        self._visa_checkout_id = visa_checkout_id

    @property
    def purchase_level(self):
        """
        Gets the purchase_level of this Ptsv2paymentsidrefundsProcessingInformation.
        Set this field to 3 to indicate that the request includes Level III data.

        :return: The purchase_level of this Ptsv2paymentsidrefundsProcessingInformation.
        :rtype: str
        """
        return self._purchase_level

    @purchase_level.setter
    def purchase_level(self, purchase_level):
        """
        Sets the purchase_level of this Ptsv2paymentsidrefundsProcessingInformation.
        Set this field to 3 to indicate that the request includes Level III data.

        :param purchase_level: The purchase_level of this Ptsv2paymentsidrefundsProcessingInformation.
        :type: str
        """
        if purchase_level is not None and len(purchase_level) > 1:
            raise ValueError("Invalid value for `purchase_level`, length must be less than or equal to `1`")

        self._purchase_level = purchase_level

    @property
    def recurring_options(self):
        """
        Gets the recurring_options of this Ptsv2paymentsidrefundsProcessingInformation.

        :return: The recurring_options of this Ptsv2paymentsidrefundsProcessingInformation.
        :rtype: Ptsv2paymentsidrefundsProcessingInformationRecurringOptions
        """
        return self._recurring_options

    @recurring_options.setter
    def recurring_options(self, recurring_options):
        """
        Sets the recurring_options of this Ptsv2paymentsidrefundsProcessingInformation.

        :param recurring_options: The recurring_options of this Ptsv2paymentsidrefundsProcessingInformation.
        :type: Ptsv2paymentsidrefundsProcessingInformationRecurringOptions
        """

        self._recurring_options = recurring_options

    @property
    def industry_data_type(self):
        """
        Gets the industry_data_type of this Ptsv2paymentsidrefundsProcessingInformation.
        Indicates that the transaction includes industry-specific data.  Possible Values: - `airline` - `restaurant` - `lodging` - `auto_rental` - `transit` - `healthcare_medical` - `healthcare_transit` - `transit`  #### Card Present, Airlines and Auto Rental You must set this field to `airline` in order for airline data to be sent to the processor. For example, if this field is not set to `airline` or is not included in the request, no airline data is sent to the processor.  You must set this field to `restaurant` in order for restaurant data to be sent to the processor. When this field is not set to `restaurant` or is not included in the request, no restaurant data is sent to the processor.  You must set this field to `auto_rental` in order for auto rental data to be sent to the processor. For example, if this field is not set to `auto_rental` or is not included in the request, no auto rental data is sent to the processor.  Restaurant data is supported only on CyberSource through VisaNet. 

        :return: The industry_data_type of this Ptsv2paymentsidrefundsProcessingInformation.
        :rtype: str
        """
        return self._industry_data_type

    @industry_data_type.setter
    def industry_data_type(self, industry_data_type):
        """
        Sets the industry_data_type of this Ptsv2paymentsidrefundsProcessingInformation.
        Indicates that the transaction includes industry-specific data.  Possible Values: - `airline` - `restaurant` - `lodging` - `auto_rental` - `transit` - `healthcare_medical` - `healthcare_transit` - `transit`  #### Card Present, Airlines and Auto Rental You must set this field to `airline` in order for airline data to be sent to the processor. For example, if this field is not set to `airline` or is not included in the request, no airline data is sent to the processor.  You must set this field to `restaurant` in order for restaurant data to be sent to the processor. When this field is not set to `restaurant` or is not included in the request, no restaurant data is sent to the processor.  You must set this field to `auto_rental` in order for auto rental data to be sent to the processor. For example, if this field is not set to `auto_rental` or is not included in the request, no auto rental data is sent to the processor.  Restaurant data is supported only on CyberSource through VisaNet. 

        :param industry_data_type: The industry_data_type of this Ptsv2paymentsidrefundsProcessingInformation.
        :type: str
        """
        if industry_data_type is not None and len(industry_data_type) > 20:
            raise ValueError("Invalid value for `industry_data_type`, length must be less than or equal to `20`")

        self._industry_data_type = industry_data_type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2paymentsidrefundsProcessingInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2paymentsDeviceInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'host_name': 'str',
        'ip_address': 'str',
        'user_agent': 'str',
        'fingerprint_session_id': 'str',
        'raw_data': 'list[Ptsv2paymentsDeviceInformationRawData]',
        'http_accept_browser_value': 'str',
        'http_accept_content': 'str',
        'http_browser_email': 'str',
        'http_browser_language': 'str',
        'http_browser_java_enabled': 'bool',
        'http_browser_java_script_enabled': 'bool',
        'http_browser_color_depth': 'str',
        'http_browser_screen_height': 'str',
        'http_browser_screen_width': 'str',
        'http_browser_time_difference': 'str',
        'user_agent_browser_value': 'str'
    }

    attribute_map = {
        'host_name': 'hostName',
        'ip_address': 'ipAddress',
        'user_agent': 'userAgent',
        'fingerprint_session_id': 'fingerprintSessionId',
        'raw_data': 'rawData',
        'http_accept_browser_value': 'httpAcceptBrowserValue',
        'http_accept_content': 'httpAcceptContent',
        'http_browser_email': 'httpBrowserEmail',
        'http_browser_language': 'httpBrowserLanguage',
        'http_browser_java_enabled': 'httpBrowserJavaEnabled',
        'http_browser_java_script_enabled': 'httpBrowserJavaScriptEnabled',
        'http_browser_color_depth': 'httpBrowserColorDepth',
        'http_browser_screen_height': 'httpBrowserScreenHeight',
        'http_browser_screen_width': 'httpBrowserScreenWidth',
        'http_browser_time_difference': 'httpBrowserTimeDifference',
        'user_agent_browser_value': 'userAgentBrowserValue'
    }

    def __init__(self, host_name=None, ip_address=None, user_agent=None, fingerprint_session_id=None, raw_data=None, http_accept_browser_value=None, http_accept_content=None, http_browser_email=None, http_browser_language=None, http_browser_java_enabled=None, http_browser_java_script_enabled=None, http_browser_color_depth=None, http_browser_screen_height=None, http_browser_screen_width=None, http_browser_time_difference=None, user_agent_browser_value=None):
        """
        Ptsv2paymentsDeviceInformation - a model defined in Swagger
        """

        self._host_name = None
        self._ip_address = None
        self._user_agent = None
        self._fingerprint_session_id = None
        self._raw_data = None
        self._http_accept_browser_value = None
        self._http_accept_content = None
        self._http_browser_email = None
        self._http_browser_language = None
        self._http_browser_java_enabled = None
        self._http_browser_java_script_enabled = None
        self._http_browser_color_depth = None
        self._http_browser_screen_height = None
        self._http_browser_screen_width = None
        self._http_browser_time_difference = None
        self._user_agent_browser_value = None

        if host_name is not None:
          self.host_name = host_name
        if ip_address is not None:
          self.ip_address = ip_address
        if user_agent is not None:
          self.user_agent = user_agent
        if fingerprint_session_id is not None:
          self.fingerprint_session_id = fingerprint_session_id
        if raw_data is not None:
          self.raw_data = raw_data
        if http_accept_browser_value is not None:
          self.http_accept_browser_value = http_accept_browser_value
        if http_accept_content is not None:
          self.http_accept_content = http_accept_content
        if http_browser_email is not None:
          self.http_browser_email = http_browser_email
        if http_browser_language is not None:
          self.http_browser_language = http_browser_language
        if http_browser_java_enabled is not None:
          self.http_browser_java_enabled = http_browser_java_enabled
        if http_browser_java_script_enabled is not None:
          self.http_browser_java_script_enabled = http_browser_java_script_enabled
        if http_browser_color_depth is not None:
          self.http_browser_color_depth = http_browser_color_depth
        if http_browser_screen_height is not None:
          self.http_browser_screen_height = http_browser_screen_height
        if http_browser_screen_width is not None:
          self.http_browser_screen_width = http_browser_screen_width
        if http_browser_time_difference is not None:
          self.http_browser_time_difference = http_browser_time_difference
        if user_agent_browser_value is not None:
          self.user_agent_browser_value = user_agent_browser_value

    @property
    def host_name(self):
        """
        Gets the host_name of this Ptsv2paymentsDeviceInformation.
        DNS resolved hostname from `ipAddress`.

        :return: The host_name of this Ptsv2paymentsDeviceInformation.
        :rtype: str
        """
        return self._host_name

    @host_name.setter
    def host_name(self, host_name):
        """
        Sets the host_name of this Ptsv2paymentsDeviceInformation.
        DNS resolved hostname from `ipAddress`.

        :param host_name: The host_name of this Ptsv2paymentsDeviceInformation.
        :type: str
        """
        if host_name is not None and len(host_name) > 60:
            raise ValueError("Invalid value for `host_name`, length must be less than or equal to `60`")

        self._host_name = host_name

    @property
    def ip_address(self):
        """
        Gets the ip_address of this Ptsv2paymentsDeviceInformation.
        IP address of the customer.  #### Used by **Authorization, Capture, and Credit** Optional field. 

        :return: The ip_address of this Ptsv2paymentsDeviceInformation.
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """
        Sets the ip_address of this Ptsv2paymentsDeviceInformation.
        IP address of the customer.  #### Used by **Authorization, Capture, and Credit** Optional field. 

        :param ip_address: The ip_address of this Ptsv2paymentsDeviceInformation.
        :type: str
        """
        if ip_address is not None and len(ip_address) > 48:
            raise ValueError("Invalid value for `ip_address`, length must be less than or equal to `48`")

        self._ip_address = ip_address

    @property
    def user_agent(self):
        """
        Gets the user_agent of this Ptsv2paymentsDeviceInformation.
        Customer’s browser as identified from the HTTP header data. For example, `Mozilla` is the value that identifies the Netscape browser. 

        :return: The user_agent of this Ptsv2paymentsDeviceInformation.
        :rtype: str
        """
        return self._user_agent

    @user_agent.setter
    def user_agent(self, user_agent):
        """
        Sets the user_agent of this Ptsv2paymentsDeviceInformation.
        Customer’s browser as identified from the HTTP header data. For example, `Mozilla` is the value that identifies the Netscape browser. 

        :param user_agent: The user_agent of this Ptsv2paymentsDeviceInformation.
        :type: str
        """
        if user_agent is not None and len(user_agent) > 40:
            raise ValueError("Invalid value for `user_agent`, length must be less than or equal to `40`")

        self._user_agent = user_agent

    @property
    def fingerprint_session_id(self):
        """
        Gets the fingerprint_session_id of this Ptsv2paymentsDeviceInformation.
        Field that contains the session ID that you send to Decision Manager to obtain the device fingerprint information. The string can contain uppercase and lowercase letters, digits, hyphen (-), and underscore (_). However, do not use the same uppercase and lowercase letters to indicate different session IDs.  The session ID must be unique for each merchant ID. You can use any string that you are already generating, such as an order number or web session ID.  The session ID must be unique for each page load, regardless of an individual’s web session ID. If a user navigates to a profiled page and is assigned a web session, navigates away from the profiled page, then navigates back to the profiled page, the generated session ID should be different and unique. You may use a web session ID, but it is preferable to use an application GUID (Globally Unique Identifier). This measure ensures that a unique ID is generated every time the page is loaded, even if it is the same user reloading the page. 

        :return: The fingerprint_session_id of this Ptsv2paymentsDeviceInformation.
        :rtype: str
        """
        return self._fingerprint_session_id

    @fingerprint_session_id.setter
    def fingerprint_session_id(self, fingerprint_session_id):
        """
        Sets the fingerprint_session_id of this Ptsv2paymentsDeviceInformation.
        Field that contains the session ID that you send to Decision Manager to obtain the device fingerprint information. The string can contain uppercase and lowercase letters, digits, hyphen (-), and underscore (_). However, do not use the same uppercase and lowercase letters to indicate different session IDs.  The session ID must be unique for each merchant ID. You can use any string that you are already generating, such as an order number or web session ID.  The session ID must be unique for each page load, regardless of an individual’s web session ID. If a user navigates to a profiled page and is assigned a web session, navigates away from the profiled page, then navigates back to the profiled page, the generated session ID should be different and unique. You may use a web session ID, but it is preferable to use an application GUID (Globally Unique Identifier). This measure ensures that a unique ID is generated every time the page is loaded, even if it is the same user reloading the page. 

        :param fingerprint_session_id: The fingerprint_session_id of this Ptsv2paymentsDeviceInformation.
        :type: str
        """

        self._fingerprint_session_id = fingerprint_session_id

    @property
    def raw_data(self):
        """
        Gets the raw_data of this Ptsv2paymentsDeviceInformation.

        :return: The raw_data of this Ptsv2paymentsDeviceInformation.
        :rtype: list[Ptsv2paymentsDeviceInformationRawData]
        """
        return self._raw_data

    @raw_data.setter
    def raw_data(self, raw_data):
        """
        Sets the raw_data of this Ptsv2paymentsDeviceInformation.

        :param raw_data: The raw_data of this Ptsv2paymentsDeviceInformation.
        :type: list[Ptsv2paymentsDeviceInformationRawData]
        """

        self._raw_data = raw_data

    @property
    def http_accept_browser_value(self):
        """
        Gets the http_accept_browser_value of this Ptsv2paymentsDeviceInformation.
        Value of the Accept header sent by the customer’s web browser. **Note** If the customer’s browser provides a value, you must include it in your request. 

        :return: The http_accept_browser_value of this Ptsv2paymentsDeviceInformation.
        :rtype: str
        """
        return self._http_accept_browser_value

    @http_accept_browser_value.setter
    def http_accept_browser_value(self, http_accept_browser_value):
        """
        Sets the http_accept_browser_value of this Ptsv2paymentsDeviceInformation.
        Value of the Accept header sent by the customer’s web browser. **Note** If the customer’s browser provides a value, you must include it in your request. 

        :param http_accept_browser_value: The http_accept_browser_value of this Ptsv2paymentsDeviceInformation.
        :type: str
        """
        if http_accept_browser_value is not None and len(http_accept_browser_value) > 255:
            raise ValueError("Invalid value for `http_accept_browser_value`, length must be less than or equal to `255`")

        self._http_accept_browser_value = http_accept_browser_value

    @property
    def http_accept_content(self):
        """
        Gets the http_accept_content of this Ptsv2paymentsDeviceInformation.
        The exact content of the HTTP accept header. 

        :return: The http_accept_content of this Ptsv2paymentsDeviceInformation.
        :rtype: str
        """
        return self._http_accept_content

    @http_accept_content.setter
    def http_accept_content(self, http_accept_content):
        """
        Sets the http_accept_content of this Ptsv2paymentsDeviceInformation.
        The exact content of the HTTP accept header. 

        :param http_accept_content: The http_accept_content of this Ptsv2paymentsDeviceInformation.
        :type: str
        """
        if http_accept_content is not None and len(http_accept_content) > 256:
            raise ValueError("Invalid value for `http_accept_content`, length must be less than or equal to `256`")

        self._http_accept_content = http_accept_content

    @property
    def http_browser_email(self):
        """
        Gets the http_browser_email of this Ptsv2paymentsDeviceInformation.
        Email address set in the customer’s browser, which may differ from customer email. 

        :return: The http_browser_email of this Ptsv2paymentsDeviceInformation.
        :rtype: str
        """
        return self._http_browser_email

    @http_browser_email.setter
    def http_browser_email(self, http_browser_email):
        """
        Sets the http_browser_email of this Ptsv2paymentsDeviceInformation.
        Email address set in the customer’s browser, which may differ from customer email. 

        :param http_browser_email: The http_browser_email of this Ptsv2paymentsDeviceInformation.
        :type: str
        """

        self._http_browser_email = http_browser_email

    @property
    def http_browser_language(self):
        """
        Gets the http_browser_language of this Ptsv2paymentsDeviceInformation.
        Value represents the browser language as defined in IETF BCP47. Example:en-US, refer  https://en.wikipedia.org/wiki/IETF_language_tag for more details. 

        :return: The http_browser_language of this Ptsv2paymentsDeviceInformation.
        :rtype: str
        """
        return self._http_browser_language

    @http_browser_language.setter
    def http_browser_language(self, http_browser_language):
        """
        Sets the http_browser_language of this Ptsv2paymentsDeviceInformation.
        Value represents the browser language as defined in IETF BCP47. Example:en-US, refer  https://en.wikipedia.org/wiki/IETF_language_tag for more details. 

        :param http_browser_language: The http_browser_language of this Ptsv2paymentsDeviceInformation.
        :type: str
        """
        if http_browser_language is not None and len(http_browser_language) > 8:
            raise ValueError("Invalid value for `http_browser_language`, length must be less than or equal to `8`")

        self._http_browser_language = http_browser_language

    @property
    def http_browser_java_enabled(self):
        """
        Gets the http_browser_java_enabled of this Ptsv2paymentsDeviceInformation.
        A Boolean value that represents the ability of the cardholder browser to execute Java. Value is returned from the navigator.javaEnabled property. Possible Values:True/False 

        :return: The http_browser_java_enabled of this Ptsv2paymentsDeviceInformation.
        :rtype: bool
        """
        return self._http_browser_java_enabled

    @http_browser_java_enabled.setter
    def http_browser_java_enabled(self, http_browser_java_enabled):
        """
        Sets the http_browser_java_enabled of this Ptsv2paymentsDeviceInformation.
        A Boolean value that represents the ability of the cardholder browser to execute Java. Value is returned from the navigator.javaEnabled property. Possible Values:True/False 

        :param http_browser_java_enabled: The http_browser_java_enabled of this Ptsv2paymentsDeviceInformation.
        :type: bool
        """

        self._http_browser_java_enabled = http_browser_java_enabled

    @property
    def http_browser_java_script_enabled(self):
        """
        Gets the http_browser_java_script_enabled of this Ptsv2paymentsDeviceInformation.
        A Boolean value that represents the ability of the cardholder browser to execute JavaScript. Possible Values:True/False. **Note**: Merchants should be able to know the values from fingerprint details of cardholder's browser. 

        :return: The http_browser_java_script_enabled of this Ptsv2paymentsDeviceInformation.
        :rtype: bool
        """
        return self._http_browser_java_script_enabled

    @http_browser_java_script_enabled.setter
    def http_browser_java_script_enabled(self, http_browser_java_script_enabled):
        """
        Sets the http_browser_java_script_enabled of this Ptsv2paymentsDeviceInformation.
        A Boolean value that represents the ability of the cardholder browser to execute JavaScript. Possible Values:True/False. **Note**: Merchants should be able to know the values from fingerprint details of cardholder's browser. 

        :param http_browser_java_script_enabled: The http_browser_java_script_enabled of this Ptsv2paymentsDeviceInformation.
        :type: bool
        """

        self._http_browser_java_script_enabled = http_browser_java_script_enabled

    @property
    def http_browser_color_depth(self):
        """
        Gets the http_browser_color_depth of this Ptsv2paymentsDeviceInformation.
        Value represents the bit depth of the color palette for displaying images, in bits per pixel. Example : 24, refer https://en.wikipedia.org/wiki/Color_depth for more details 

        :return: The http_browser_color_depth of this Ptsv2paymentsDeviceInformation.
        :rtype: str
        """
        return self._http_browser_color_depth

    @http_browser_color_depth.setter
    def http_browser_color_depth(self, http_browser_color_depth):
        """
        Sets the http_browser_color_depth of this Ptsv2paymentsDeviceInformation.
        Value represents the bit depth of the color palette for displaying images, in bits per pixel. Example : 24, refer https://en.wikipedia.org/wiki/Color_depth for more details 

        :param http_browser_color_depth: The http_browser_color_depth of this Ptsv2paymentsDeviceInformation.
        :type: str
        """
        if http_browser_color_depth is not None and len(http_browser_color_depth) > 2:
            raise ValueError("Invalid value for `http_browser_color_depth`, length must be less than or equal to `2`")

        self._http_browser_color_depth = http_browser_color_depth

    @property
    def http_browser_screen_height(self):
        """
        Gets the http_browser_screen_height of this Ptsv2paymentsDeviceInformation.
        Total height of the Cardholder's scree in pixels, example: 864. 

        :return: The http_browser_screen_height of this Ptsv2paymentsDeviceInformation.
        :rtype: str
        """
        return self._http_browser_screen_height

    @http_browser_screen_height.setter
    def http_browser_screen_height(self, http_browser_screen_height):
        """
        Sets the http_browser_screen_height of this Ptsv2paymentsDeviceInformation.
        Total height of the Cardholder's scree in pixels, example: 864. 

        :param http_browser_screen_height: The http_browser_screen_height of this Ptsv2paymentsDeviceInformation.
        :type: str
        """
        if http_browser_screen_height is not None and len(http_browser_screen_height) > 6:
            raise ValueError("Invalid value for `http_browser_screen_height`, length must be less than or equal to `6`")

        self._http_browser_screen_height = http_browser_screen_height

    @property
    def http_browser_screen_width(self):
        """
        Gets the http_browser_screen_width of this Ptsv2paymentsDeviceInformation.
        Total width of the cardholder's screen in pixels. Example: 1536. 

        :return: The http_browser_screen_width of this Ptsv2paymentsDeviceInformation.
        :rtype: str
        """
        return self._http_browser_screen_width

    @http_browser_screen_width.setter
    def http_browser_screen_width(self, http_browser_screen_width):
        """
        Sets the http_browser_screen_width of this Ptsv2paymentsDeviceInformation.
        Total width of the cardholder's screen in pixels. Example: 1536. 

        :param http_browser_screen_width: The http_browser_screen_width of this Ptsv2paymentsDeviceInformation.
        :type: str
        """
        if http_browser_screen_width is not None and len(http_browser_screen_width) > 6:
            raise ValueError("Invalid value for `http_browser_screen_width`, length must be less than or equal to `6`")

        self._http_browser_screen_width = http_browser_screen_width

    @property
    def http_browser_time_difference(self):
        """
        Gets the http_browser_time_difference of this Ptsv2paymentsDeviceInformation.
        Time difference between UTC time and the cardholder browser local time, in minutes, Example:300 

        :return: The http_browser_time_difference of this Ptsv2paymentsDeviceInformation.
        :rtype: str
        """
        return self._http_browser_time_difference

    @http_browser_time_difference.setter
    def http_browser_time_difference(self, http_browser_time_difference):
        """
        Sets the http_browser_time_difference of this Ptsv2paymentsDeviceInformation.
        Time difference between UTC time and the cardholder browser local time, in minutes, Example:300 

        :param http_browser_time_difference: The http_browser_time_difference of this Ptsv2paymentsDeviceInformation.
        :type: str
        """
        if http_browser_time_difference is not None and len(http_browser_time_difference) > 5:
            raise ValueError("Invalid value for `http_browser_time_difference`, length must be less than or equal to `5`")

        self._http_browser_time_difference = http_browser_time_difference

    @property
    def user_agent_browser_value(self):
        """
        Gets the user_agent_browser_value of this Ptsv2paymentsDeviceInformation.
        Value of the User-Agent header sent by the customer’s web browser. Note If the customer’s browser provides a value, you must include it in your request. 

        :return: The user_agent_browser_value of this Ptsv2paymentsDeviceInformation.
        :rtype: str
        """
        return self._user_agent_browser_value

    @user_agent_browser_value.setter
    def user_agent_browser_value(self, user_agent_browser_value):
        """
        Sets the user_agent_browser_value of this Ptsv2paymentsDeviceInformation.
        Value of the User-Agent header sent by the customer’s web browser. Note If the customer’s browser provides a value, you must include it in your request. 

        :param user_agent_browser_value: The user_agent_browser_value of this Ptsv2paymentsDeviceInformation.
        :type: str
        """
        if user_agent_browser_value is not None and len(user_agent_browser_value) > 255:
            raise ValueError("Invalid value for `user_agent_browser_value`, length must be less than or equal to `255`")

        self._user_agent_browser_value = user_agent_browser_value

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2paymentsDeviceInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'request_id': 'str',
        'transaction_reference_number': 'str',
        'time': 'datetime',
        'authorization_request_id': 'str',
        'amount': 'str',
        'currency_code': 'str',
        'code': 'str',
        'rcode': 'str'
    }

    attribute_map = {
        'request_id': 'requestId',
        'transaction_reference_number': 'transactionReferenceNumber',
        'time': 'time',
        'authorization_request_id': 'authorizationRequestId',
        'amount': 'amount',
        'currency_code': 'currencyCode',
        'code': 'code',
        'rcode': 'rcode'
    }

    def __init__(self, request_id=None, transaction_reference_number=None, time=None, authorization_request_id=None, amount=None, currency_code=None, code=None, rcode=None):
        """
        ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations - a model defined in Swagger
        """

        self._request_id = None
        self._transaction_reference_number = None
        self._time = None
        self._authorization_request_id = None
        self._amount = None
        self._currency_code = None
        self._code = None
        self._rcode = None

        if request_id is not None:
          self.request_id = request_id
        if transaction_reference_number is not None:
          self.transaction_reference_number = transaction_reference_number
        if time is not None:
          self.time = time
        if authorization_request_id is not None:
          self.authorization_request_id = authorization_request_id
        if amount is not None:
          self.amount = amount
        if currency_code is not None:
          self.currency_code = currency_code
        if code is not None:
          self.code = code
        if rcode is not None:
          self.rcode = rcode

    @property
    def request_id(self):
        """
        Gets the request_id of this ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations.
        An unique identification number assigned by CyberSource to identify the submitted request.

        :return: The request_id of this ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations.
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """
        Sets the request_id of this ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations.
        An unique identification number assigned by CyberSource to identify the submitted request.

        :param request_id: The request_id of this ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations.
        :type: str
        """

        self._request_id = request_id

    @property
    def transaction_reference_number(self):
        """
        Gets the transaction_reference_number of this ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations.
        Authorization Transaction Reference Number

        :return: The transaction_reference_number of this ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations.
        :rtype: str
        """
        return self._transaction_reference_number

    @transaction_reference_number.setter
    def transaction_reference_number(self, transaction_reference_number):
        """
        Sets the transaction_reference_number of this ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations.
        Authorization Transaction Reference Number

        :param transaction_reference_number: The transaction_reference_number of this ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations.
        :type: str
        """

        self._transaction_reference_number = transaction_reference_number

    @property
    def time(self):
        """
        Gets the time of this ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations.
        Authorization Date

        :return: The time of this ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations.
        :rtype: datetime
        """
        return self._time

    @time.setter
    def time(self, time):
        """
        Sets the time of this ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations.
        Authorization Date

        :param time: The time of this ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations.
        :type: datetime
        """

        self._time = time

    @property
    def authorization_request_id(self):
        """
        Gets the authorization_request_id of this ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations.
        Authorization Request Id

        :return: The authorization_request_id of this ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations.
        :rtype: str
        """
        return self._authorization_request_id

    @authorization_request_id.setter
    def authorization_request_id(self, authorization_request_id):
        """
        Sets the authorization_request_id of this ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations.
        Authorization Request Id

        :param authorization_request_id: The authorization_request_id of this ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations.
        :type: str
        """

        self._authorization_request_id = authorization_request_id

    @property
    def amount(self):
        """
        Gets the amount of this ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations.
        Authorization Amount

        :return: The amount of this ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations.
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """
        Sets the amount of this ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations.
        Authorization Amount

        :param amount: The amount of this ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations.
        :type: str
        """

        self._amount = amount

    @property
    def currency_code(self):
        """
        Gets the currency_code of this ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations.
        Valid ISO 4217 ALPHA-3 currency code

        :return: The currency_code of this ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations.
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """
        Sets the currency_code of this ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations.
        Valid ISO 4217 ALPHA-3 currency code

        :param currency_code: The currency_code of this ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations.
        :type: str
        """

        self._currency_code = currency_code

    @property
    def code(self):
        """
        Gets the code of this ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations.
        Authorization Code

        :return: The code of this ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations.
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """
        Sets the code of this ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations.
        Authorization Code

        :param code: The code of this ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations.
        :type: str
        """

        self._code = code

    @property
    def rcode(self):
        """
        Gets the rcode of this ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations.
        Authorization RCode

        :return: The rcode of this ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations.
        :rtype: str
        """
        return self._rcode

    @rcode.setter
    def rcode(self, rcode):
        """
        Sets the rcode of this ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations.
        Authorization RCode

        :param rcode: The rcode of this ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations.
        :type: str
        """

        self._rcode = rcode

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ReportingV3PurchaseRefundDetailsGet200ResponseAuthorizations):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'report_mime_type': 'str',
        'report_frequency': 'str',
        'report_name': 'str',
        'timezone': 'str',
        'start_time': 'str',
        'start_day': 'int',
        'report_filters': 'dict(str, list[str])',
        'report_preferences': 'Reportingv3reportsReportPreferences'
    }

    attribute_map = {
        'report_mime_type': 'reportMimeType',
        'report_frequency': 'reportFrequency',
        'report_name': 'reportName',
        'timezone': 'timezone',
        'start_time': 'startTime',
        'start_day': 'startDay',
        'report_filters': 'reportFilters',
        'report_preferences': 'reportPreferences'
    }

    def __init__(self, report_mime_type=None, report_frequency=None, report_name=None, timezone=None, start_time=None, start_day=None, report_filters=None, report_preferences=None):
        """
        ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings - a model defined in Swagger
        """

        self._report_mime_type = None
        self._report_frequency = None
        self._report_name = None
        self._timezone = None
        self._start_time = None
        self._start_day = None
        self._report_filters = None
        self._report_preferences = None

        if report_mime_type is not None:
          self.report_mime_type = report_mime_type
        if report_frequency is not None:
          self.report_frequency = report_frequency
        if report_name is not None:
          self.report_name = report_name
        if timezone is not None:
          self.timezone = timezone
        if start_time is not None:
          self.start_time = start_time
        if start_day is not None:
          self.start_day = start_day
        if report_filters is not None:
          self.report_filters = report_filters
        if report_preferences is not None:
          self.report_preferences = report_preferences

    @property
    def report_mime_type(self):
        """
        Gets the report_mime_type of this ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings.
        Report Format Valid values:   - application/xml   - text/csv 

        :return: The report_mime_type of this ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings.
        :rtype: str
        """
        return self._report_mime_type

    @report_mime_type.setter
    def report_mime_type(self, report_mime_type):
        """
        Sets the report_mime_type of this ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings.
        Report Format Valid values:   - application/xml   - text/csv 

        :param report_mime_type: The report_mime_type of this ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings.
        :type: str
        """

        self._report_mime_type = report_mime_type

    @property
    def report_frequency(self):
        """
        Gets the report_frequency of this ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings.
        Report Frequency Value Valid Values:   - DAILY   - WEEKLY   - MONTHLY   - ADHOC 

        :return: The report_frequency of this ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings.
        :rtype: str
        """
        return self._report_frequency

    @report_frequency.setter
    def report_frequency(self, report_frequency):
        """
        Sets the report_frequency of this ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings.
        Report Frequency Value Valid Values:   - DAILY   - WEEKLY   - MONTHLY   - ADHOC 

        :param report_frequency: The report_frequency of this ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings.
        :type: str
        """

        self._report_frequency = report_frequency

    @property
    def report_name(self):
        """
        Gets the report_name of this ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings.
        Report Name

        :return: The report_name of this ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings.
        :rtype: str
        """
        return self._report_name

    @report_name.setter
    def report_name(self, report_name):
        """
        Sets the report_name of this ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings.
        Report Name

        :param report_name: The report_name of this ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings.
        :type: str
        """

        self._report_name = report_name

    @property
    def timezone(self):
        """
        Gets the timezone of this ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings.
        Time Zone

        :return: The timezone of this ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings.
        :rtype: str
        """
        return self._timezone

    @timezone.setter
    def timezone(self, timezone):
        """
        Sets the timezone of this ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings.
        Time Zone

        :param timezone: The timezone of this ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings.
        :type: str
        """

        self._timezone = timezone

    @property
    def start_time(self):
        """
        Gets the start_time of this ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings.
        Start Time

        :return: The start_time of this ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings.
        :rtype: str
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """
        Sets the start_time of this ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings.
        Start Time

        :param start_time: The start_time of this ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings.
        :type: str
        """

        self._start_time = start_time

    @property
    def start_day(self):
        """
        Gets the start_day of this ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings.
        Start Day

        :return: The start_day of this ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings.
        :rtype: int
        """
        return self._start_day

    @start_day.setter
    def start_day(self, start_day):
        """
        Sets the start_day of this ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings.
        Start Day

        :param start_day: The start_day of this ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings.
        :type: int
        """

        self._start_day = start_day

    @property
    def report_filters(self):
        """
        Gets the report_filters of this ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings.
        List of filters to apply

        :return: The report_filters of this ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings.
        :rtype: dict(str, list[str])
        """
        return self._report_filters

    @report_filters.setter
    def report_filters(self, report_filters):
        """
        Sets the report_filters of this ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings.
        List of filters to apply

        :param report_filters: The report_filters of this ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings.
        :type: dict(str, list[str])
        """

        self._report_filters = report_filters

    @property
    def report_preferences(self):
        """
        Gets the report_preferences of this ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings.

        :return: The report_preferences of this ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings.
        :rtype: Reportingv3reportsReportPreferences
        """
        return self._report_preferences

    @report_preferences.setter
    def report_preferences(self, report_preferences):
        """
        Sets the report_preferences of this ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings.

        :param report_preferences: The report_preferences of this ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings.
        :type: Reportingv3reportsReportPreferences
        """

        self._report_preferences = report_preferences

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ReportingV3ReportDefinitionsNameGet200ResponseDefaultSettings):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Kmsv2keyssymClientReferenceInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'code': 'str',
        'comments': 'str',
        'partner': 'Vasv2taxClientReferenceInformationPartner'
    }

    attribute_map = {
        'code': 'code',
        'comments': 'comments',
        'partner': 'partner'
    }

    def __init__(self, code=None, comments=None, partner=None):
        """
        Kmsv2keyssymClientReferenceInformation - a model defined in Swagger
        """

        self._code = None
        self._comments = None
        self._partner = None

        if code is not None:
          self.code = code
        if comments is not None:
          self.comments = comments
        if partner is not None:
          self.partner = partner

    @property
    def code(self):
        """
        Gets the code of this Kmsv2keyssymClientReferenceInformation.
        Client-generated order reference or tracking number. CyberSource recommends that you send a unique value. 

        :return: The code of this Kmsv2keyssymClientReferenceInformation.
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """
        Sets the code of this Kmsv2keyssymClientReferenceInformation.
        Client-generated order reference or tracking number. CyberSource recommends that you send a unique value. 

        :param code: The code of this Kmsv2keyssymClientReferenceInformation.
        :type: str
        """
        if code is not None and len(code) > 50:
            raise ValueError("Invalid value for `code`, length must be less than or equal to `50`")

        self._code = code

    @property
    def comments(self):
        """
        Gets the comments of this Kmsv2keyssymClientReferenceInformation.
        Comments

        :return: The comments of this Kmsv2keyssymClientReferenceInformation.
        :rtype: str
        """
        return self._comments

    @comments.setter
    def comments(self, comments):
        """
        Sets the comments of this Kmsv2keyssymClientReferenceInformation.
        Comments

        :param comments: The comments of this Kmsv2keyssymClientReferenceInformation.
        :type: str
        """

        self._comments = comments

    @property
    def partner(self):
        """
        Gets the partner of this Kmsv2keyssymClientReferenceInformation.

        :return: The partner of this Kmsv2keyssymClientReferenceInformation.
        :rtype: Vasv2taxClientReferenceInformationPartner
        """
        return self._partner

    @partner.setter
    def partner(self, partner):
        """
        Sets the partner of this Kmsv2keyssymClientReferenceInformation.

        :param partner: The partner of this Kmsv2keyssymClientReferenceInformation.
        :type: Vasv2taxClientReferenceInformationPartner
        """

        self._partner = partner

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Kmsv2keyssymClientReferenceInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Vasv2taxOrderInformationShippingDetails(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ship_from_locality': 'str',
        'ship_from_country': 'str',
        'ship_from_postal_code': 'str',
        'ship_from_administrative_area': 'str'
    }

    attribute_map = {
        'ship_from_locality': 'shipFromLocality',
        'ship_from_country': 'shipFromCountry',
        'ship_from_postal_code': 'shipFromPostalCode',
        'ship_from_administrative_area': 'shipFromAdministrativeArea'
    }

    def __init__(self, ship_from_locality=None, ship_from_country=None, ship_from_postal_code=None, ship_from_administrative_area=None):
        """
        Vasv2taxOrderInformationShippingDetails - a model defined in Swagger
        """

        self._ship_from_locality = None
        self._ship_from_country = None
        self._ship_from_postal_code = None
        self._ship_from_administrative_area = None

        if ship_from_locality is not None:
          self.ship_from_locality = ship_from_locality
        if ship_from_country is not None:
          self.ship_from_country = ship_from_country
        if ship_from_postal_code is not None:
          self.ship_from_postal_code = ship_from_postal_code
        if ship_from_administrative_area is not None:
          self.ship_from_administrative_area = ship_from_administrative_area

    @property
    def ship_from_locality(self):
        """
        Gets the ship_from_locality of this Vasv2taxOrderInformationShippingDetails.
        City where the product is shipped from. This field is used only when the `orderInformation.shipTo.administrativeArea` and `orderInformation.shipTo.country` fields are present.  **NOTE** If this field appears in a `lineItems` object, then the value of this field in the `lineItems` object overrides the value of the corresponding field at the request-level or order-level object.  #### Tax Calculation This field is used to determine tax rules and/or rates applied to the transaction based on sourcing.  Optional for U.S. and Canadian taxes. Not applicable to international and value added taxes. 

        :return: The ship_from_locality of this Vasv2taxOrderInformationShippingDetails.
        :rtype: str
        """
        return self._ship_from_locality

    @ship_from_locality.setter
    def ship_from_locality(self, ship_from_locality):
        """
        Sets the ship_from_locality of this Vasv2taxOrderInformationShippingDetails.
        City where the product is shipped from. This field is used only when the `orderInformation.shipTo.administrativeArea` and `orderInformation.shipTo.country` fields are present.  **NOTE** If this field appears in a `lineItems` object, then the value of this field in the `lineItems` object overrides the value of the corresponding field at the request-level or order-level object.  #### Tax Calculation This field is used to determine tax rules and/or rates applied to the transaction based on sourcing.  Optional for U.S. and Canadian taxes. Not applicable to international and value added taxes. 

        :param ship_from_locality: The ship_from_locality of this Vasv2taxOrderInformationShippingDetails.
        :type: str
        """
        if ship_from_locality is not None and len(ship_from_locality) > 50:
            raise ValueError("Invalid value for `ship_from_locality`, length must be less than or equal to `50`")

        self._ship_from_locality = ship_from_locality

    @property
    def ship_from_country(self):
        """
        Gets the ship_from_country of this Vasv2taxOrderInformationShippingDetails.
        Country from which the order is shipped. This field is used only when `orderInformation.shippingDetails.shipFromLocality` and `orderInformation.shippingDetails.shipFromAdministrativeArea` are present. Use the [ISO Standard Country Codes](http://apps.cybersource.com/library/documentation/sbc/quickref/countries_alpha_list.pdf).  **NOTE** If this field appears in a `lineItems` object, then the value of this field in the `lineItems` object overrides the value of the corresponding field at the request-level or order-level object.  #### Tax Calculation This field is used to determine tax rules and/ or rates applied to the transaction based on sourcing.  Optional for U.S., Canadian, international tax, and value added taxes. 

        :return: The ship_from_country of this Vasv2taxOrderInformationShippingDetails.
        :rtype: str
        """
        return self._ship_from_country

    @ship_from_country.setter
    def ship_from_country(self, ship_from_country):
        """
        Sets the ship_from_country of this Vasv2taxOrderInformationShippingDetails.
        Country from which the order is shipped. This field is used only when `orderInformation.shippingDetails.shipFromLocality` and `orderInformation.shippingDetails.shipFromAdministrativeArea` are present. Use the [ISO Standard Country Codes](http://apps.cybersource.com/library/documentation/sbc/quickref/countries_alpha_list.pdf).  **NOTE** If this field appears in a `lineItems` object, then the value of this field in the `lineItems` object overrides the value of the corresponding field at the request-level or order-level object.  #### Tax Calculation This field is used to determine tax rules and/ or rates applied to the transaction based on sourcing.  Optional for U.S., Canadian, international tax, and value added taxes. 

        :param ship_from_country: The ship_from_country of this Vasv2taxOrderInformationShippingDetails.
        :type: str
        """
        if ship_from_country is not None and len(ship_from_country) > 2:
            raise ValueError("Invalid value for `ship_from_country`, length must be less than or equal to `2`")

        self._ship_from_country = ship_from_country

    @property
    def ship_from_postal_code(self):
        """
        Gets the ship_from_postal_code of this Vasv2taxOrderInformationShippingDetails.
        Postal code where the product is shipped from.  #### Tax Calculation This field is used to determine tax rules and/or rates applied to the transaction based on sourcing.  Optional for U.S. and Canadian taxes. Not applicable to international and value added taxes. 

        :return: The ship_from_postal_code of this Vasv2taxOrderInformationShippingDetails.
        :rtype: str
        """
        return self._ship_from_postal_code

    @ship_from_postal_code.setter
    def ship_from_postal_code(self, ship_from_postal_code):
        """
        Sets the ship_from_postal_code of this Vasv2taxOrderInformationShippingDetails.
        Postal code where the product is shipped from.  #### Tax Calculation This field is used to determine tax rules and/or rates applied to the transaction based on sourcing.  Optional for U.S. and Canadian taxes. Not applicable to international and value added taxes. 

        :param ship_from_postal_code: The ship_from_postal_code of this Vasv2taxOrderInformationShippingDetails.
        :type: str
        """
        if ship_from_postal_code is not None and len(ship_from_postal_code) > 10:
            raise ValueError("Invalid value for `ship_from_postal_code`, length must be less than or equal to `10`")

        self._ship_from_postal_code = ship_from_postal_code

    @property
    def ship_from_administrative_area(self):
        """
        Gets the ship_from_administrative_area of this Vasv2taxOrderInformationShippingDetails.
        State from which the order is shipped. This field is used only when `orderInformation.shippingDetails.shipFromLocality` and `orderInformation.shippingDetails.shipFromCountry` are present. Use the [State, Province, and Territory Codes for the United States and Canada](http://apps.cybersource.com/library/documentation/sbc/quickref/states_and_provinces.pdf).  **NOTE** If this field appears in a `lineItems` object, then the value of this field in the `lineItems` object overrides the value of the corresponding field at the request-level or order-level object.  #### Tax Calculation This field is used to determine tax rules and/or rates applied to the transaction based on sourcing.  Optional for U.S. and Canadian taxes. Not applicable to international and value added taxes. 

        :return: The ship_from_administrative_area of this Vasv2taxOrderInformationShippingDetails.
        :rtype: str
        """
        return self._ship_from_administrative_area

    @ship_from_administrative_area.setter
    def ship_from_administrative_area(self, ship_from_administrative_area):
        """
        Sets the ship_from_administrative_area of this Vasv2taxOrderInformationShippingDetails.
        State from which the order is shipped. This field is used only when `orderInformation.shippingDetails.shipFromLocality` and `orderInformation.shippingDetails.shipFromCountry` are present. Use the [State, Province, and Territory Codes for the United States and Canada](http://apps.cybersource.com/library/documentation/sbc/quickref/states_and_provinces.pdf).  **NOTE** If this field appears in a `lineItems` object, then the value of this field in the `lineItems` object overrides the value of the corresponding field at the request-level or order-level object.  #### Tax Calculation This field is used to determine tax rules and/or rates applied to the transaction based on sourcing.  Optional for U.S. and Canadian taxes. Not applicable to international and value added taxes. 

        :param ship_from_administrative_area: The ship_from_administrative_area of this Vasv2taxOrderInformationShippingDetails.
        :type: str
        """
        if ship_from_administrative_area is not None and len(ship_from_administrative_area) > 2:
            raise ValueError("Invalid value for `ship_from_administrative_area`, length must be less than or equal to `2`")

        self._ship_from_administrative_area = ship_from_administrative_area

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Vasv2taxOrderInformationShippingDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class InvoicingV2InvoicesAllGet200ResponseLinks(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        '_self': 'PtsV2PaymentsPost201ResponseLinksSelf',
        'next': 'PtsV2PaymentsPost201ResponseLinksSelf',
        'previous': 'PtsV2PaymentsPost201ResponseLinksSelf'
    }

    attribute_map = {
        '_self': 'self',
        'next': 'next',
        'previous': 'previous'
    }

    def __init__(self, _self=None, next=None, previous=None):
        """
        InvoicingV2InvoicesAllGet200ResponseLinks - a model defined in Swagger
        """

        self.__self = None
        self._next = None
        self._previous = None

        if _self is not None:
          self._self = _self
        if next is not None:
          self.next = next
        if previous is not None:
          self.previous = previous

    @property
    def _self(self):
        """
        Gets the _self of this InvoicingV2InvoicesAllGet200ResponseLinks.

        :return: The _self of this InvoicingV2InvoicesAllGet200ResponseLinks.
        :rtype: PtsV2PaymentsPost201ResponseLinksSelf
        """
        return self.__self

    @_self.setter
    def _self(self, _self):
        """
        Sets the _self of this InvoicingV2InvoicesAllGet200ResponseLinks.

        :param _self: The _self of this InvoicingV2InvoicesAllGet200ResponseLinks.
        :type: PtsV2PaymentsPost201ResponseLinksSelf
        """

        self.__self = _self

    @property
    def next(self):
        """
        Gets the next of this InvoicingV2InvoicesAllGet200ResponseLinks.

        :return: The next of this InvoicingV2InvoicesAllGet200ResponseLinks.
        :rtype: PtsV2PaymentsPost201ResponseLinksSelf
        """
        return self._next

    @next.setter
    def next(self, next):
        """
        Sets the next of this InvoicingV2InvoicesAllGet200ResponseLinks.

        :param next: The next of this InvoicingV2InvoicesAllGet200ResponseLinks.
        :type: PtsV2PaymentsPost201ResponseLinksSelf
        """

        self._next = next

    @property
    def previous(self):
        """
        Gets the previous of this InvoicingV2InvoicesAllGet200ResponseLinks.

        :return: The previous of this InvoicingV2InvoicesAllGet200ResponseLinks.
        :rtype: PtsV2PaymentsPost201ResponseLinksSelf
        """
        return self._previous

    @previous.setter
    def previous(self, previous):
        """
        Sets the previous of this InvoicingV2InvoicesAllGet200ResponseLinks.

        :param previous: The previous of this InvoicingV2InvoicesAllGet200ResponseLinks.
        :type: PtsV2PaymentsPost201ResponseLinksSelf
        """

        self._previous = previous

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, InvoicingV2InvoicesAllGet200ResponseLinks):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class PtsV2PaymentsCapturesPost201ResponseProcessorInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'transaction_id': 'str'
    }

    attribute_map = {
        'transaction_id': 'transactionId'
    }

    def __init__(self, transaction_id=None):
        """
        PtsV2PaymentsCapturesPost201ResponseProcessorInformation - a model defined in Swagger
        """

        self._transaction_id = None

        if transaction_id is not None:
          self.transaction_id = transaction_id

    @property
    def transaction_id(self):
        """
        Gets the transaction_id of this PtsV2PaymentsCapturesPost201ResponseProcessorInformation.
        Processor transaction ID.  This value identifies the transaction on a host system. This value is supported only for Moneris. It contains this information:   - Terminal used to process the transaction  - Shift during which the transaction took place  - Batch number  - Transaction number within the batch  You must store this value. If you give the customer a receipt, display this value on the receipt.  Example For the value 66012345001069003:   - Terminal ID = 66012345  - Shift number = 001  - Batch number = 069  - Transaction number = 003 

        :return: The transaction_id of this PtsV2PaymentsCapturesPost201ResponseProcessorInformation.
        :rtype: str
        """
        return self._transaction_id

    @transaction_id.setter
    def transaction_id(self, transaction_id):
        """
        Sets the transaction_id of this PtsV2PaymentsCapturesPost201ResponseProcessorInformation.
        Processor transaction ID.  This value identifies the transaction on a host system. This value is supported only for Moneris. It contains this information:   - Terminal used to process the transaction  - Shift during which the transaction took place  - Batch number  - Transaction number within the batch  You must store this value. If you give the customer a receipt, display this value on the receipt.  Example For the value 66012345001069003:   - Terminal ID = 66012345  - Shift number = 001  - Batch number = 069  - Transaction number = 003 

        :param transaction_id: The transaction_id of this PtsV2PaymentsCapturesPost201ResponseProcessorInformation.
        :type: str
        """
        if transaction_id is not None and len(transaction_id) > 18:
            raise ValueError("Invalid value for `transaction_id`, length must be less than or equal to `18`")

        self._transaction_id = transaction_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PtsV2PaymentsCapturesPost201ResponseProcessorInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Reportingv3reportsReportPreferences(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'signed_amounts': 'bool',
        'field_name_convention': 'str'
    }

    attribute_map = {
        'signed_amounts': 'signedAmounts',
        'field_name_convention': 'fieldNameConvention'
    }

    def __init__(self, signed_amounts=None, field_name_convention=None):
        """
        Reportingv3reportsReportPreferences - a model defined in Swagger
        """

        self._signed_amounts = None
        self._field_name_convention = None

        if signed_amounts is not None:
          self.signed_amounts = signed_amounts
        if field_name_convention is not None:
          self.field_name_convention = field_name_convention

    @property
    def signed_amounts(self):
        """
        Gets the signed_amounts of this Reportingv3reportsReportPreferences.
        Indicator to determine whether negative sign infront of amount for all refunded transaction

        :return: The signed_amounts of this Reportingv3reportsReportPreferences.
        :rtype: bool
        """
        return self._signed_amounts

    @signed_amounts.setter
    def signed_amounts(self, signed_amounts):
        """
        Sets the signed_amounts of this Reportingv3reportsReportPreferences.
        Indicator to determine whether negative sign infront of amount for all refunded transaction

        :param signed_amounts: The signed_amounts of this Reportingv3reportsReportPreferences.
        :type: bool
        """

        self._signed_amounts = signed_amounts

    @property
    def field_name_convention(self):
        """
        Gets the field_name_convention of this Reportingv3reportsReportPreferences.
        Specify the field naming convention to be followed in reports (applicable to only csv report formats)  Valid values: - SOAPI - SCMP 

        :return: The field_name_convention of this Reportingv3reportsReportPreferences.
        :rtype: str
        """
        return self._field_name_convention

    @field_name_convention.setter
    def field_name_convention(self, field_name_convention):
        """
        Sets the field_name_convention of this Reportingv3reportsReportPreferences.
        Specify the field naming convention to be followed in reports (applicable to only csv report formats)  Valid values: - SOAPI - SCMP 

        :param field_name_convention: The field_name_convention of this Reportingv3reportsReportPreferences.
        :type: str
        """

        self._field_name_convention = field_name_convention

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Reportingv3reportsReportPreferences):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class RiskV1AddressVerificationsPost201Response(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'links': 'PtsV2IncrementalAuthorizationPatch201ResponseLinks',
        'id': 'str',
        'submit_time_utc': 'str',
        'submit_time_local': 'str',
        'status': 'str',
        'message': 'str',
        'client_reference_information': 'PtsV2IncrementalAuthorizationPatch201ResponseClientReferenceInformation',
        'address_verification_information': 'RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation',
        'error_information': 'RiskV1AddressVerificationsPost201ResponseErrorInformation'
    }

    attribute_map = {
        'links': '_links',
        'id': 'id',
        'submit_time_utc': 'submitTimeUtc',
        'submit_time_local': 'submitTimeLocal',
        'status': 'status',
        'message': 'message',
        'client_reference_information': 'clientReferenceInformation',
        'address_verification_information': 'addressVerificationInformation',
        'error_information': 'errorInformation'
    }

    def __init__(self, links=None, id=None, submit_time_utc=None, submit_time_local=None, status=None, message=None, client_reference_information=None, address_verification_information=None, error_information=None):
        """
        RiskV1AddressVerificationsPost201Response - a model defined in Swagger
        """

        self._links = None
        self._id = None
        self._submit_time_utc = None
        self._submit_time_local = None
        self._status = None
        self._message = None
        self._client_reference_information = None
        self._address_verification_information = None
        self._error_information = None

        if links is not None:
          self.links = links
        if id is not None:
          self.id = id
        if submit_time_utc is not None:
          self.submit_time_utc = submit_time_utc
        if submit_time_local is not None:
          self.submit_time_local = submit_time_local
        if status is not None:
          self.status = status
        if message is not None:
          self.message = message
        if client_reference_information is not None:
          self.client_reference_information = client_reference_information
        if address_verification_information is not None:
          self.address_verification_information = address_verification_information
        if error_information is not None:
          self.error_information = error_information

    @property
    def links(self):
        """
        Gets the links of this RiskV1AddressVerificationsPost201Response.

        :return: The links of this RiskV1AddressVerificationsPost201Response.
        :rtype: PtsV2IncrementalAuthorizationPatch201ResponseLinks
        """
        return self._links

    @links.setter
    def links(self, links):
        """
        Sets the links of this RiskV1AddressVerificationsPost201Response.

        :param links: The links of this RiskV1AddressVerificationsPost201Response.
        :type: PtsV2IncrementalAuthorizationPatch201ResponseLinks
        """

        self._links = links

    @property
    def id(self):
        """
        Gets the id of this RiskV1AddressVerificationsPost201Response.
        An unique identification number to identify the submitted request. It is also appended to the endpoint of the resource.  On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.  #### PIN debit Returned for all PIN debit services. 

        :return: The id of this RiskV1AddressVerificationsPost201Response.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this RiskV1AddressVerificationsPost201Response.
        An unique identification number to identify the submitted request. It is also appended to the endpoint of the resource.  On incremental authorizations, this value with be the same as the identification number returned in the original authorization response.  #### PIN debit Returned for all PIN debit services. 

        :param id: The id of this RiskV1AddressVerificationsPost201Response.
        :type: str
        """
        if id is not None and len(id) > 26:
            raise ValueError("Invalid value for `id`, length must be less than or equal to `26`")

        self._id = id

    @property
    def submit_time_utc(self):
        """
        Gets the submit_time_utc of this RiskV1AddressVerificationsPost201Response.
        Time of request in UTC. Format: `YYYY-MM-DDThh:mm:ssZ` **Example** `2016-08-11T22:47:57Z` equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The `T` separates the date and the time. The `Z` indicates UTC.  Returned by authorization service.  #### PIN debit Time when the PIN debit credit, PIN debit purchase or PIN debit reversal was requested.  Returned by PIN debit credit, PIN debit purchase or PIN debit reversal. 

        :return: The submit_time_utc of this RiskV1AddressVerificationsPost201Response.
        :rtype: str
        """
        return self._submit_time_utc

    @submit_time_utc.setter
    def submit_time_utc(self, submit_time_utc):
        """
        Sets the submit_time_utc of this RiskV1AddressVerificationsPost201Response.
        Time of request in UTC. Format: `YYYY-MM-DDThh:mm:ssZ` **Example** `2016-08-11T22:47:57Z` equals August 11, 2016, at 22:47:57 (10:47:57 p.m.). The `T` separates the date and the time. The `Z` indicates UTC.  Returned by authorization service.  #### PIN debit Time when the PIN debit credit, PIN debit purchase or PIN debit reversal was requested.  Returned by PIN debit credit, PIN debit purchase or PIN debit reversal. 

        :param submit_time_utc: The submit_time_utc of this RiskV1AddressVerificationsPost201Response.
        :type: str
        """

        self._submit_time_utc = submit_time_utc

    @property
    def submit_time_local(self):
        """
        Gets the submit_time_local of this RiskV1AddressVerificationsPost201Response.
        Time that the transaction was submitted in local time.

        :return: The submit_time_local of this RiskV1AddressVerificationsPost201Response.
        :rtype: str
        """
        return self._submit_time_local

    @submit_time_local.setter
    def submit_time_local(self, submit_time_local):
        """
        Sets the submit_time_local of this RiskV1AddressVerificationsPost201Response.
        Time that the transaction was submitted in local time.

        :param submit_time_local: The submit_time_local of this RiskV1AddressVerificationsPost201Response.
        :type: str
        """

        self._submit_time_local = submit_time_local

    @property
    def status(self):
        """
        Gets the status of this RiskV1AddressVerificationsPost201Response.
        The status for the call can be: - COMPLETED - INVALID_REQUEST - DECLINED 

        :return: The status of this RiskV1AddressVerificationsPost201Response.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this RiskV1AddressVerificationsPost201Response.
        The status for the call can be: - COMPLETED - INVALID_REQUEST - DECLINED 

        :param status: The status of this RiskV1AddressVerificationsPost201Response.
        :type: str
        """

        self._status = status

    @property
    def message(self):
        """
        Gets the message of this RiskV1AddressVerificationsPost201Response.
        The message describing the reason of the status. Value can be   - Apartment number missing or not found.   - Insufficient address information.   - House/Box number not found on street.   - Multiple address matches were found.   - P.O. Box identifier not found or out of range.   - Route service identifier not found or out of range.   - Street name not found in Postal code.   - Postal code not found in database.   - Unable to verify or correct address.   - Multiple addres matches were found (international)   - Address match not found (no reason given)   - Unsupported character set 

        :return: The message of this RiskV1AddressVerificationsPost201Response.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this RiskV1AddressVerificationsPost201Response.
        The message describing the reason of the status. Value can be   - Apartment number missing or not found.   - Insufficient address information.   - House/Box number not found on street.   - Multiple address matches were found.   - P.O. Box identifier not found or out of range.   - Route service identifier not found or out of range.   - Street name not found in Postal code.   - Postal code not found in database.   - Unable to verify or correct address.   - Multiple addres matches were found (international)   - Address match not found (no reason given)   - Unsupported character set 

        :param message: The message of this RiskV1AddressVerificationsPost201Response.
        :type: str
        """

        self._message = message

    @property
    def client_reference_information(self):
        """
        Gets the client_reference_information of this RiskV1AddressVerificationsPost201Response.

        :return: The client_reference_information of this RiskV1AddressVerificationsPost201Response.
        :rtype: PtsV2IncrementalAuthorizationPatch201ResponseClientReferenceInformation
        """
        return self._client_reference_information

    @client_reference_information.setter
    def client_reference_information(self, client_reference_information):
        """
        Sets the client_reference_information of this RiskV1AddressVerificationsPost201Response.

        :param client_reference_information: The client_reference_information of this RiskV1AddressVerificationsPost201Response.
        :type: PtsV2IncrementalAuthorizationPatch201ResponseClientReferenceInformation
        """

        self._client_reference_information = client_reference_information

    @property
    def address_verification_information(self):
        """
        Gets the address_verification_information of this RiskV1AddressVerificationsPost201Response.

        :return: The address_verification_information of this RiskV1AddressVerificationsPost201Response.
        :rtype: RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation
        """
        return self._address_verification_information

    @address_verification_information.setter
    def address_verification_information(self, address_verification_information):
        """
        Sets the address_verification_information of this RiskV1AddressVerificationsPost201Response.

        :param address_verification_information: The address_verification_information of this RiskV1AddressVerificationsPost201Response.
        :type: RiskV1AddressVerificationsPost201ResponseAddressVerificationInformation
        """

        self._address_verification_information = address_verification_information

    @property
    def error_information(self):
        """
        Gets the error_information of this RiskV1AddressVerificationsPost201Response.

        :return: The error_information of this RiskV1AddressVerificationsPost201Response.
        :rtype: RiskV1AddressVerificationsPost201ResponseErrorInformation
        """
        return self._error_information

    @error_information.setter
    def error_information(self, error_information):
        """
        Sets the error_information of this RiskV1AddressVerificationsPost201Response.

        :param error_information: The error_information of this RiskV1AddressVerificationsPost201Response.
        :type: RiskV1AddressVerificationsPost201ResponseErrorInformation
        """

        self._error_information = error_information

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, RiskV1AddressVerificationsPost201Response):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ReportingV3PurchaseRefundDetailsGet200ResponseSettlements(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'request_id': 'str',
        'transaction_type': 'str',
        'submission_time': 'datetime',
        'amount': 'str',
        'currency_code': 'str',
        'payment_method': 'str',
        'wallet_type': 'str',
        'payment_type': 'str',
        'account_suffix': 'str',
        'cybersource_batch_time': 'datetime',
        'cybersource_batch_id': 'str',
        'card_type': 'str',
        'debit_network': 'str'
    }

    attribute_map = {
        'request_id': 'requestId',
        'transaction_type': 'transactionType',
        'submission_time': 'submissionTime',
        'amount': 'amount',
        'currency_code': 'currencyCode',
        'payment_method': 'paymentMethod',
        'wallet_type': 'walletType',
        'payment_type': 'paymentType',
        'account_suffix': 'accountSuffix',
        'cybersource_batch_time': 'cybersourceBatchTime',
        'cybersource_batch_id': 'cybersourceBatchId',
        'card_type': 'cardType',
        'debit_network': 'debitNetwork'
    }

    def __init__(self, request_id=None, transaction_type=None, submission_time=None, amount=None, currency_code=None, payment_method=None, wallet_type=None, payment_type=None, account_suffix=None, cybersource_batch_time=None, cybersource_batch_id=None, card_type=None, debit_network=None):
        """
        ReportingV3PurchaseRefundDetailsGet200ResponseSettlements - a model defined in Swagger
        """

        self._request_id = None
        self._transaction_type = None
        self._submission_time = None
        self._amount = None
        self._currency_code = None
        self._payment_method = None
        self._wallet_type = None
        self._payment_type = None
        self._account_suffix = None
        self._cybersource_batch_time = None
        self._cybersource_batch_id = None
        self._card_type = None
        self._debit_network = None

        if request_id is not None:
          self.request_id = request_id
        if transaction_type is not None:
          self.transaction_type = transaction_type
        if submission_time is not None:
          self.submission_time = submission_time
        if amount is not None:
          self.amount = amount
        if currency_code is not None:
          self.currency_code = currency_code
        if payment_method is not None:
          self.payment_method = payment_method
        if wallet_type is not None:
          self.wallet_type = wallet_type
        if payment_type is not None:
          self.payment_type = payment_type
        if account_suffix is not None:
          self.account_suffix = account_suffix
        if cybersource_batch_time is not None:
          self.cybersource_batch_time = cybersource_batch_time
        if cybersource_batch_id is not None:
          self.cybersource_batch_id = cybersource_batch_id
        if card_type is not None:
          self.card_type = card_type
        if debit_network is not None:
          self.debit_network = debit_network

    @property
    def request_id(self):
        """
        Gets the request_id of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        An unique identification number assigned by CyberSource to identify the submitted request.

        :return: The request_id of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """
        Sets the request_id of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        An unique identification number assigned by CyberSource to identify the submitted request.

        :param request_id: The request_id of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        :type: str
        """

        self._request_id = request_id

    @property
    def transaction_type(self):
        """
        Gets the transaction_type of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        Transaction Type

        :return: The transaction_type of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        :rtype: str
        """
        return self._transaction_type

    @transaction_type.setter
    def transaction_type(self, transaction_type):
        """
        Sets the transaction_type of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        Transaction Type

        :param transaction_type: The transaction_type of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        :type: str
        """

        self._transaction_type = transaction_type

    @property
    def submission_time(self):
        """
        Gets the submission_time of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        Submission Date

        :return: The submission_time of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        :rtype: datetime
        """
        return self._submission_time

    @submission_time.setter
    def submission_time(self, submission_time):
        """
        Sets the submission_time of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        Submission Date

        :param submission_time: The submission_time of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        :type: datetime
        """

        self._submission_time = submission_time

    @property
    def amount(self):
        """
        Gets the amount of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        Amount

        :return: The amount of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """
        Sets the amount of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        Amount

        :param amount: The amount of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        :type: str
        """

        self._amount = amount

    @property
    def currency_code(self):
        """
        Gets the currency_code of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        Valid ISO 4217 ALPHA-3 currency code

        :return: The currency_code of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        :rtype: str
        """
        return self._currency_code

    @currency_code.setter
    def currency_code(self, currency_code):
        """
        Sets the currency_code of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        Valid ISO 4217 ALPHA-3 currency code

        :param currency_code: The currency_code of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        :type: str
        """

        self._currency_code = currency_code

    @property
    def payment_method(self):
        """
        Gets the payment_method of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        payment method

        :return: The payment_method of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        :rtype: str
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """
        Sets the payment_method of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        payment method

        :param payment_method: The payment_method of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        :type: str
        """

        self._payment_method = payment_method

    @property
    def wallet_type(self):
        """
        Gets the wallet_type of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        Solution Type (Wallet)

        :return: The wallet_type of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        :rtype: str
        """
        return self._wallet_type

    @wallet_type.setter
    def wallet_type(self, wallet_type):
        """
        Sets the wallet_type of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        Solution Type (Wallet)

        :param wallet_type: The wallet_type of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        :type: str
        """

        self._wallet_type = wallet_type

    @property
    def payment_type(self):
        """
        Gets the payment_type of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        Payment Type

        :return: The payment_type of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        :rtype: str
        """
        return self._payment_type

    @payment_type.setter
    def payment_type(self, payment_type):
        """
        Sets the payment_type of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        Payment Type

        :param payment_type: The payment_type of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        :type: str
        """

        self._payment_type = payment_type

    @property
    def account_suffix(self):
        """
        Gets the account_suffix of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        Account Suffix

        :return: The account_suffix of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        :rtype: str
        """
        return self._account_suffix

    @account_suffix.setter
    def account_suffix(self, account_suffix):
        """
        Sets the account_suffix of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        Account Suffix

        :param account_suffix: The account_suffix of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        :type: str
        """

        self._account_suffix = account_suffix

    @property
    def cybersource_batch_time(self):
        """
        Gets the cybersource_batch_time of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        Cybersource Batch Time

        :return: The cybersource_batch_time of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        :rtype: datetime
        """
        return self._cybersource_batch_time

    @cybersource_batch_time.setter
    def cybersource_batch_time(self, cybersource_batch_time):
        """
        Sets the cybersource_batch_time of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        Cybersource Batch Time

        :param cybersource_batch_time: The cybersource_batch_time of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        :type: datetime
        """

        self._cybersource_batch_time = cybersource_batch_time

    @property
    def cybersource_batch_id(self):
        """
        Gets the cybersource_batch_id of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        Cybersource Batch Id

        :return: The cybersource_batch_id of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        :rtype: str
        """
        return self._cybersource_batch_id

    @cybersource_batch_id.setter
    def cybersource_batch_id(self, cybersource_batch_id):
        """
        Sets the cybersource_batch_id of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        Cybersource Batch Id

        :param cybersource_batch_id: The cybersource_batch_id of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        :type: str
        """

        self._cybersource_batch_id = cybersource_batch_id

    @property
    def card_type(self):
        """
        Gets the card_type of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        Card Type

        :return: The card_type of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        :rtype: str
        """
        return self._card_type

    @card_type.setter
    def card_type(self, card_type):
        """
        Sets the card_type of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        Card Type

        :param card_type: The card_type of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        :type: str
        """

        self._card_type = card_type

    @property
    def debit_network(self):
        """
        Gets the debit_network of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        Debit Network

        :return: The debit_network of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        :rtype: str
        """
        return self._debit_network

    @debit_network.setter
    def debit_network(self, debit_network):
        """
        Sets the debit_network of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        Debit Network

        :param debit_network: The debit_network of this ReportingV3PurchaseRefundDetailsGet200ResponseSettlements.
        :type: str
        """

        self._debit_network = debit_network

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ReportingV3PurchaseRefundDetailsGet200ResponseSettlements):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
